@@ -13,6 +13,7 @@
 #ifndef _LINKINCLUDESH_
 #define _LINKINCLUDESH_
 
+#ifndef SWIG
 #include <stdbool.h> /* Needed for bool typedef */
 #include <stdio.h>   /* Needed for FILE* below */
 #include <link-grammar/link-features.h>
@@ -29,6 +30,7 @@ LINK_BEGIN_DECLS
 	#define false                           0
 	#define __bool_true_false_are_defined   1
 #endif
+#endif /* !SWIG */
 
 /**********************************************************************
  *
@@ -44,9 +46,53 @@ link_public_api(const char *)
 link_public_api(const char *)
 	linkgrammar_get_dict_version(Dictionary);
 
+link_public_api(const char *)
+	linkgrammar_get_configuration(void);
+
 link_public_api(const char *)
 	linkgrammar_get_dict_locale(Dictionary);
 
+/**********************************************************************
+ *
+ * Functions and definitions for the error handler.
+ *
+ ***********************************************************************/
+typedef enum
+{
+	lg_Fatal = 1,
+	lg_Error,
+	lg_Warn,
+	lg_Info,
+	lg_Debug,
+	lg_Trace,
+	lg_None
+} lg_error_severity;
+
+/* Raw error message. */
+typedef struct
+{
+	/* err_ctxt ec; */
+	lg_error_severity severity;
+	const char *severity_label;
+	const char *text;
+} lg_errinfo;
+
+/* Error handler callback function. */
+typedef void (*lg_error_handler)(lg_errinfo *, void *);
+
+link_public_api(lg_error_handler)
+     lg_error_set_handler(lg_error_handler, void *data);
+link_public_api(const void *)
+     lg_error_set_handler_data(void * data);
+link_public_api(char *)
+     lg_error_formatmsg(lg_errinfo *lge);
+link_public_api(int)
+     lg_error_printall(lg_error_handler, void *data);
+link_public_api(int)
+     lg_error_clearall(void);
+link_public_api(bool)
+     lg_error_flush(void);
+
 /**********************************************************************
  *
  * Functions to manipulate Dictionaries
@@ -67,6 +113,8 @@ link_public_api(void)
      dictionary_set_data_dir(const char * path);
 link_public_api(char *)
      dictionary_get_data_dir(void);
+link_public_api(FILE *)
+	  linkgrammar_open_data_file(const char *);
 
 /**********************************************************************
  *
@@ -138,14 +186,20 @@ link_public_api(void)
      parse_options_set_cost_model_type(Parse_Options opts, Cost_Model_type cm);
 link_public_api(Cost_Model_type)
      parse_options_get_cost_model_type(Parse_Options opts);
+link_public_api(void)
+     parse_options_set_perform_pp_prune(Parse_Options opts, bool pp_prune);
+link_public_api(bool)
+     parse_options_get_perform_pp_prune(Parse_Options opts);
 link_public_api(void)
      parse_options_set_use_sat_parser(Parse_Options opts, bool use_sat_solver);
 link_public_api(bool)
      parse_options_get_use_sat_parser(Parse_Options opts);
+#ifdef USE_VITERBI
 link_public_api(void)
      parse_options_set_use_viterbi(Parse_Options opts, bool use_viterbi);
 link_public_api(bool)
      parse_options_get_use_viterbi(Parse_Options opts);
+#endif
 link_public_api(bool)
      parse_options_timer_expired(Parse_Options opts);
 link_public_api(bool)
@@ -226,6 +280,8 @@ link_public_api(double)
      sentence_disjunct_cost(Sentence sent, LinkageIdx linkage_num);
 link_public_api(int)
      sentence_link_cost(Sentence sent, LinkageIdx linkage_num);
+link_public_api(bool)
+     sentence_display_wordgraph(Sentence sent, const char *modestr);
 
 /**********************************************************************
  *
@@ -314,21 +370,32 @@ link_public_api(double)
 link_public_api(const char *)
      linkage_get_violation_name(const Linkage linkage);
 
+/* Experimental API - subject to changes. */
+link_public_api(size_t)
+     linkage_get_word_byte_start(const Linkage linkage, WordIdx w);
+link_public_api(size_t)
+     linkage_get_word_byte_end(const Linkage linkage, WordIdx w);
+link_public_api(size_t)
+     linkage_get_word_char_start(const Linkage linkage, WordIdx w);
+link_public_api(size_t)
+     linkage_get_word_char_end(const Linkage linkage, WordIdx w);
+
 
 /**********************************************************************
  *
  * Internal functions -- do not use these in new code!
- * These are not intended for general public use, but are required to
- * get the link-parser executable to link under MSVC6.
+ * They are used in the link-parser code (which needs their signature to
+ * compile), but are not intended for general public use.
  *
  ***********************************************************************/
 
-link_public_api(void)
+link_public_api(size_t)
+     utf8_strwidth(const char *);
+
+link_public_api(char *)
      dict_display_word_expr(Dictionary dict, const char *, Parse_Options opts);
-link_public_api(void)
+link_public_api(char *)
      dict_display_word_info(Dictionary dict, const char *, Parse_Options opts);
-link_public_api(void)
-     left_print_string(FILE* fp, const char *, const char *);
 link_public_api(bool)
      lg_expand_disjunct_list(Sentence sent);
 
@@ -336,7 +403,7 @@ link_public_api(bool)
  *
  * Internal functions -- do not use these in new code!
  * These are not intended for general public use, but are required to
- * work around certain Micorsoft Windows linking oddities
+ * work around certain Microsoft Windows linking oddities
  * (specifically, to be callable from the JNI bindings library.)
  *
  ***********************************************************************/
@@ -351,7 +418,7 @@ link_public_api(void)
 #define GNUC_PRINTF( format_idx, arg_idx )
 #endif
 
-link_public_api(void)
+link_public_api(int)
      prt_error(const char *fmt, ...) GNUC_PRINTF(1,2);
 
 /*******************************************************
@@ -367,28 +434,14 @@ link_public_api(void)
 #define GNUC_DEPRECATED
 #endif
 
-#if defined(_MSC_VER) && _MSC_VER > 1200  /* Only if newer than MSVC6 */ 
+#if defined(_MSC_VER)
  #define MS_DEPRECATED __declspec(deprecated)
 #else
  #define MS_DEPRECATED
 #endif
 
-/**********************************************************************
- *
- * Functions that allow special-purpose post-processing of linkages
- *
- ***********************************************************************/
-
-/** Do not use in new code! */
-typedef struct Postprocessor_s PostProcessor;
-
-MS_DEPRECATED link_public_api(PostProcessor *)
-     post_process_open(const char *path) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(void)
-     post_process_close(PostProcessor *) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(void)
-     linkage_post_process(Linkage, PostProcessor *) GNUC_DEPRECATED;
-
+#ifndef SWIG
 LINK_END_DECLS
+#endif /* !SWIG */
 
 #endif
