@@ -80,8 +80,8 @@ class ParseOptions(object):
     def verbosity(self, value):
         if not isinstance(value, int):
             raise TypeError("Verbosity must be set to an integer")
-        if value not in range(0,15):
-            raise ValueError("Verbosity levels can be any integer between 0 and 15 inclusive")
+        if value not in range(0,120):
+            raise ValueError("Verbosity levels can be any integer between 0 and 120 inclusive")
         clg.parse_options_set_verbosity(self._obj, value)
 
     @property
@@ -483,11 +483,13 @@ class Sentence(object):
     def __init__(self, text, lgdict, parse_options):
         # Keep all args passed into clg.* functions.
         self.text, self.dict, self.parse_options = text, lgdict, parse_options
+        clg._py_incref(self.dict) # The Sentence struct refers to the Dictionary struct
         self._obj = clg.sentence_create(self.text, self.dict._obj)
 
     def __del__(self):
         if hasattr(self, '_obj'):
             clg.sentence_delete(self._obj)
+            clg._py_decref(self.dict)
             del self._obj
 
     def split(self, parse_options=None):
@@ -505,11 +507,12 @@ class Sentence(object):
         return clg.sentence_null_count(self._obj)
 
     class sentence_parse(object):
-        def __init__(self, sent):
+        def __init__(self, sent, parse_options):
             self.sent = sent
             self.num = 0
-            self.rc = clg.sentence_parse(sent._obj, sent.parse_options._obj)
-            if clg.parse_options_timer_expired(sent.parse_options._obj):
+            self.parse_options = sent.parse_options if parse_options is None else parse_options
+            self.rc = clg.sentence_parse(sent._obj, self.parse_options._obj)
+            if clg.parse_options_timer_expired(self.parse_options._obj):
                 raise LG_TimerExhausted()
 
         def __nonzero__(self):
@@ -529,7 +532,7 @@ class Sentence(object):
         def next(self):
             if self.num == clg.sentence_num_valid_linkages(self.sent._obj):
                 raise StopIteration()
-            linkage = Linkage(self.num, self.sent, self.sent.parse_options._obj)
+            linkage = Linkage(self.num, self.sent, self.parse_options._obj)
             if not linkage:  # SAT sentinel value
                 raise StopIteration()
             self.num += 1
@@ -537,5 +540,5 @@ class Sentence(object):
 
         __next__ = next             # Account python3
 
-    def parse(self):
-        return self.sentence_parse(self)
+    def parse(self, parse_options=None):
+        return self.sentence_parse(self, parse_options)
